<<< Date Index >>>     <<< Thread Index >>>

Re: Mutt ignoring Reply-To



[moving from mutt-users]

Jukka Salmi --> mutt-users (2007-08-02 13:41:13 +0200):
> Rado S --> mutt-users (2007-08-01 19:34:48 +0200):
> > =- Jukka Salmi wrote on Wed  1.Aug'07 at 11:53:41 +0200 -=
> > 
> > > I'm using Mutt 1.5.16. When replying to a mail which has a
> > > Reply-To header while reply_to is set, the address from the From
> > > header instead of the one from the Reply-To header ends up as the
> > > recipient address. I'd expect this behaviour only if reply_to is
> > > unset.
> > 
> > Have a look at mutt-dev archives, reply-to behaviour has been
> > discussed there in more detail.
> 
> Thanks for the hint. For the archives:
> 
>       http://dev.mutt.org/trac/ticket/2934

Hmm, glancing at the code, wouldn't the attached patch make everybody
happy?


Regards, Jukka

-- 
bashian roulette:
$ ((RANDOM%6)) || rm -rf ~
diff -r 6bc60516fffa send.c
--- a/send.c    Wed Jul 25 11:16:49 2007 -0700
+++ b/send.c    Thu Aug 02 14:38:28 2007 +0200
@@ -454,9 +454,9 @@ static int default_to (ADDRESS **to, ENV
   if (flags & SENDLISTREPLY)
     return 0;
 
-  if (!option(OPTREPLYSELF) && mutt_addr_is_user (env->from))
-  {
-    /* mail is from the user, assume replying to recipients */
+  if (!option(OPTREPLYSELF) && mutt_addr_is_user (env->from) && !env->reply_to)
+  {
+    /* mail is from the user and Reply-To not set, assume replying to 
recipients */
     rfc822_append (to, env->to);
   }
   else if (env->reply_to)
@@ -496,7 +496,14 @@ static int default_to (ADDRESS **to, ENV
        break;
 
       case M_NO:
-       rfc822_append (to, env->from);
+       if (!option(OPTREPLYSELF) && mutt_addr_is_user (env->from))
+       {
+         rfc822_append (to, env->to);
+       }
+       else
+       {
+         rfc822_append (to, env->from);
+       }
        break;
 
       default: